pub struct SecretServiceClient<T> { /* private fields */ }Implementations
Sourceimpl SecretServiceClient<Channel>
impl SecretServiceClient<Channel>
Sourceimpl<T> SecretServiceClient<T>
impl<T> SecretServiceClient<T>
pub fn new(inner: T) -> Self
pub fn with_origin(inner: T, origin: Uri) -> Self
pub fn with_interceptor<F>( inner: T, interceptor: F, ) -> SecretServiceClient<InterceptedService<T, F>>
Sourcepub fn send_compressed(self, encoding: CompressionEncoding) -> Self
pub fn send_compressed(self, encoding: CompressionEncoding) -> Self
Compress requests with the given encoding.
This requires the server to support it otherwise it might respond with an error.
Sourcepub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
pub fn accept_compressed(self, encoding: CompressionEncoding) -> Self
Enable decompressing responses.
Sourcepub fn max_decoding_message_size(self, limit: usize) -> Self
pub fn max_decoding_message_size(self, limit: usize) -> Self
Limits the maximum size of a decoded message.
Default: 4MB
Sourcepub fn max_encoding_message_size(self, limit: usize) -> Self
pub fn max_encoding_message_size(self, limit: usize) -> Self
Limits the maximum size of an encoded message.
Default: usize::MAX
pub async fn describe( &mut self, request: impl IntoRequest<DescribeRequest>, ) -> Result<Response<DescribeResponse>, Status>
pub async fn resolve( &mut self, request: impl IntoRequest<ResolveRequest>, ) -> Result<Response<ResolveResponse>, Status>
Sourcepub async fn inspect_binding(
&mut self,
request: impl IntoRequest<InspectBindingRequest>,
) -> Result<Response<InspectBindingResponse>, Status>
pub async fn inspect_binding( &mut self, request: impl IntoRequest<InspectBindingRequest>, ) -> Result<Response<InspectBindingResponse>, Status>
Read-only metadata inspection. This reports whether the exact logical extract exists without returning or decrypting its value.
pub async fn store( &mut self, request: impl IntoRequest<StoreRequest>, ) -> Result<Response<StoreResponse>, Status>
pub async fn delete( &mut self, request: impl IntoRequest<DeleteRequest>, ) -> Result<Response<DeleteResponse>, Status>
pub async fn inspect_recipient_policy( &mut self, request: impl IntoRequest<InspectRecipientPolicyRequest>, ) -> Result<Response<InspectRecipientPolicyResponse>, Status>
pub async fn apply_recipient_policy( &mut self, request: impl IntoRequest<ApplyRecipientPolicyRequest>, ) -> Result<Response<ApplyRecipientPolicyResponse>, Status>
pub async fn resolve_public_artifact( &mut self, request: impl IntoRequest<ResolvePublicArtifactRequest>, ) -> Result<Response<ResolvePublicArtifactResponse>, Status>
pub async fn store_public_artifact( &mut self, request: impl IntoRequest<StorePublicArtifactRequest>, ) -> Result<Response<StorePublicArtifactResponse>, Status>