SecretService

Trait SecretService 

pub trait SecretService:
    Send
    + Sync
    + 'static {
    // Required methods
    fn describe<'life0, 'async_trait>(
        &'life0 self,
        request: Request<DescribeRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<DescribeResponse>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn resolve<'life0, 'async_trait>(
        &'life0 self,
        request: Request<ResolveRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<ResolveResponse>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn inspect_binding<'life0, 'async_trait>(
        &'life0 self,
        request: Request<InspectBindingRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<InspectBindingResponse>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn store<'life0, 'async_trait>(
        &'life0 self,
        request: Request<StoreRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<StoreResponse>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn delete<'life0, 'async_trait>(
        &'life0 self,
        request: Request<DeleteRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<DeleteResponse>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn inspect_recipient_policy<'life0, 'async_trait>(
        &'life0 self,
        request: Request<InspectRecipientPolicyRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<InspectRecipientPolicyResponse>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn apply_recipient_policy<'life0, 'async_trait>(
        &'life0 self,
        request: Request<ApplyRecipientPolicyRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<ApplyRecipientPolicyResponse>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn resolve_public_artifact<'life0, 'async_trait>(
        &'life0 self,
        request: Request<ResolvePublicArtifactRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<ResolvePublicArtifactResponse>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
    fn store_public_artifact<'life0, 'async_trait>(
        &'life0 self,
        request: Request<StorePublicArtifactRequest>,
    ) -> Pin<Box<dyn Future<Output = Result<Response<StorePublicArtifactResponse>, Status>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait;
}
Generated trait containing gRPC methods that should be implemented for use with SecretServiceServer.

Required Methods

fn describe<'life0, 'async_trait>( &'life0 self, request: Request<DescribeRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<DescribeResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn resolve<'life0, 'async_trait>( &'life0 self, request: Request<ResolveRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ResolveResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn inspect_binding<'life0, 'async_trait>( &'life0 self, request: Request<InspectBindingRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<InspectBindingResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Read-only metadata inspection. This reports whether the exact logical extract exists without returning or decrypting its value.

fn store<'life0, 'async_trait>( &'life0 self, request: Request<StoreRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<StoreResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn delete<'life0, 'async_trait>( &'life0 self, request: Request<DeleteRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<DeleteResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn inspect_recipient_policy<'life0, 'async_trait>( &'life0 self, request: Request<InspectRecipientPolicyRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<InspectRecipientPolicyResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn apply_recipient_policy<'life0, 'async_trait>( &'life0 self, request: Request<ApplyRecipientPolicyRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ApplyRecipientPolicyResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn resolve_public_artifact<'life0, 'async_trait>( &'life0 self, request: Request<ResolvePublicArtifactRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<ResolvePublicArtifactResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

fn store_public_artifact<'life0, 'async_trait>( &'life0 self, request: Request<StorePublicArtifactRequest>, ) -> Pin<Box<dyn Future<Output = Result<Response<StorePublicArtifactResponse>, Status>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait,

Implementors