pub struct InspectRecipientPolicyRequest {
pub context: Option<RequestContext>,
pub identity_id: String,
pub age_recipient: String,
pub creation_rule_path_regex: String,
pub document_references: Vec<String>,
pub recipient_alias: String,
}Fields
context: Option<RequestContext>identity_id: Stringage_recipient: Stringcreation_rule_path_regex: Stringdocument_references: Vec<String>recipient_alias: StringStable backend policy key owned by this managed identity. It may match a legacy YAML anchor, but the backend is free to normalize anchor syntax.