pub struct ResolvePublicArtifactRequest {
pub context: Option<RequestContext>,
pub binding: Option<PublicArtifactBinding>,
}Fields
context: Option<RequestContext>binding: Option<PublicArtifactBinding>Trait Implementations
Sourceimpl Clone for ResolvePublicArtifactRequest
impl Clone for ResolvePublicArtifactRequest
Sourcefn clone(&self) -> ResolvePublicArtifactRequest
fn clone(&self) -> ResolvePublicArtifactRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResolvePublicArtifactRequest
impl Debug for ResolvePublicArtifactRequest
Sourceimpl Hash for ResolvePublicArtifactRequest
impl Hash for ResolvePublicArtifactRequest
Sourceimpl Message for ResolvePublicArtifactRequest
impl Message for ResolvePublicArtifactRequest
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for ResolvePublicArtifactRequest
impl PartialEq for ResolvePublicArtifactRequest
Sourcefn eq(&self, other: &ResolvePublicArtifactRequest) -> bool
fn eq(&self, other: &ResolvePublicArtifactRequest) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for ResolvePublicArtifactRequest
impl StructuralPartialEq for ResolvePublicArtifactRequest